@@ -2,7 +2,7 @@ import cloudscraper, websocket, requests, base64, json, time
 from typing import Union, Generator, Any
 from websocket import create_connection
 from random import randbytes
-from utils.errors import errors
+from .utils.errors import errors
 
 scraper = cloudscraper.create_scraper()
 
